<xsl:stylesheet 
  version="1.0" 
  exclude-result-prefixes="x d xsl msxsl cmswrt"
  xmlns:x="http://www.w3.org/2001/XMLSchema" 
  xmlns:d="http://schemas.microsoft.com/sharepoint/dsp" 
  xmlns:cmswrt="http://schemas.microsoft.com/WebParts/v3/Publishing/runtime"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:msxsl="urn:schemas-microsoft-com:xslt"
  xmlns:ddwrt="http://schemas.microsoft.com/WebParts/v2/DataView/runtime">    
 
	<xsl:template name="removeMarkup">
		<xsl:param name="string" />
		<xsl:choose>
			<xsl:when test="contains($string, '&lt;')">
				<xsl:variable name="nextString">
					<xsl:call-template name="removeMarkup">
						<xsl:with-param name="string" select="substring-after($string, '&gt;')" />
					</xsl:call-template>
				</xsl:variable>
				<xsl:value-of select="concat(substring-before($string, '&lt;'), $nextString)" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$string" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>	

<!-- item styles for Pediatric CoE -->

	<xsl:template name="PediatricCoENewsStyle" match="Row[@Style='PediatricCoENewsStyle']" mode="itemstyle">

		<xsl:variable name="SafeLinkUrl">
			<xsl:call-template name="OuterTemplate.GetSafeLink">
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="SafeImageUrl">
			<xsl:call-template name="OuterTemplate.GetSafeStaticUrl">
				<xsl:with-param name="UrlColumnName" select="'Picture'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="DisplayTitle">
			<xsl:call-template name="OuterTemplate.GetTitle">
				<xsl:with-param name="Title" select="@Title"/>
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="LinkTarget">
			<xsl:if test="@OpenInNewWindow = 'True'" >_blank</xsl:if>
		</xsl:variable>
        
		<xsl:variable name="Article">
			<xsl:call-template name="removeMarkup">
				<xsl:with-param name="string" select="@Article"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="Created">
			<xsl:value-of select="ddwrt:FormatDateTime(string(@Date) ,1033 ,'MM.dd.yyyy')" />
		</xsl:variable>

		<xsl:variable name="back">
			<xsl:value-of select="concat('/pediatriccoe',$SafeLinkUrl,'&amp;source=/pediatriccoe/Pages/Home.aspx')" />
		</xsl:variable>
        
		<div id="BiotechnewsStyle" class="pcd">        
			<a href="{$back}" target="{$LinkTarget}" title="{@LinkToolTip}" class="titel">
				<em><xsl:value-of select="$Created"/></em> - <xsl:value-of select="$DisplayTitle"/>
			</a>
			<xsl:value-of select="substring($Article, 0, 120)" disable-output-escaping="yes" />...   	         
		</div>
	</xsl:template>

	<xsl:template name="PediatricCoETopNewsStyle" match="Row[@Style='PediatricCoETopNewsStyle']" mode="itemstyle">

		<xsl:variable name="SafeLinkUrl">
			<xsl:call-template name="OuterTemplate.GetSafeLink">
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="SafeImageUrl">
			<xsl:call-template name="OuterTemplate.GetSafeStaticUrl">
				<xsl:with-param name="UrlColumnName" select="'Picture'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="DisplayTitle">
			<xsl:call-template name="OuterTemplate.GetTitle">
				<xsl:with-param name="Title" select="@Title"/>
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="LinkTarget">
			<xsl:if test="@OpenInNewWindow = 'True'" >_blank</xsl:if>
		</xsl:variable>
        
		<xsl:variable name="Article">
			<xsl:call-template name="removeMarkup">
				<xsl:with-param name="string" select="@Article"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="Created">
			<xsl:value-of select="ddwrt:FormatDateTime(string(@Date) ,1033 ,'MM.dd.yyyy')" />
		</xsl:variable>

		<xsl:variable name="back">
			<xsl:value-of select="concat('/pediatriccoe',$SafeLinkUrl,'&amp;source=/pediatriccoe/Pages/Home.aspx')" />
		</xsl:variable>
        
		<table cellpadding="4" style="background-color: #5B8A39; border: 1px solid black;" width="100%">

			<tr>
			<td>
			<font color="#ffffff" style="font-face: Verdanda; font-size: 12pt;"><b>Pediatric News Highlight</b></font>
			</td>
			</tr>

			<tr>
			<td align="center">

			<xsl:if test="string-length($SafeImageUrl) != 0"> 
				<a href="{$back}" target="{$LinkTarget}" class="img">
					<img class="image" style="border:1px solid #ffffff;" src="{$SafeImageUrl}" alt="{@ImageUrlAltText}" />
				</a>
			</xsl:if>

			</td>
			</tr>
			<tr>
			<td>

			<a href="{$back}" target="{$LinkTarget}" title="{@LinkToolTip}">
				<font color="#ffffff"><b><xsl:value-of select="$DisplayTitle"/></b></font>
			</a>
			<br />
			<font color="#ffffff"><xsl:value-of select="substring($Article, 0, 135)" disable-output-escaping="yes" />...</font>&#160;&#160;<a href="{$back}" target="{$LinkTarget}" class="img"><font color="#ffffff"><b>&#62;&#62;</b></font></a>

			</td>
			</tr>
		</table> 

	</xsl:template>

	<xsl:template name="PediatricCoERegUSNewsStyle" match="Row[@Style='PediatricCoERegUSNewsStyle']" mode="itemstyle">

		<xsl:variable name="SafeLinkUrl">
			<xsl:call-template name="OuterTemplate.GetSafeLink">
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="SafeImageUrl">
			<xsl:call-template name="OuterTemplate.GetSafeStaticUrl">
				<xsl:with-param name="UrlColumnName" select="'Picture'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="DisplayTitle">
			<xsl:call-template name="OuterTemplate.GetTitle">
				<xsl:with-param name="Title" select="@Title"/>
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="LinkTarget">
			<xsl:if test="@OpenInNewWindow = 'True'" >_blank</xsl:if>
		</xsl:variable>
        
		<xsl:variable name="Article">
			<xsl:call-template name="removeMarkup">
				<xsl:with-param name="string" select="@Article"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="Created">
			<xsl:value-of select="ddwrt:FormatDateTime(string(@Date) ,1033 ,'MM.dd.yyyy')" />
		</xsl:variable>

		<xsl:variable name="back">
			<xsl:value-of select="concat('/pediatriccoe',$SafeLinkUrl,'&amp;source=/pediatriccoe/Pages/RegulatoryUS.aspx')" />
		</xsl:variable>
        
		<div id="BiotechnewsStyle" class="pcd">        
			<a href="{$back}" target="{$LinkTarget}" title="{@LinkToolTip}" class="titel">
				<xsl:value-of select="$DisplayTitle"/>
			</a>
			<xsl:value-of select="substring($Article, 0, 120)" disable-output-escaping="yes" />...   	         
		</div>
	</xsl:template>

	<xsl:template name="PediatricCoERegEUNewsStyle" match="Row[@Style='PediatricCoERegEUNewsStyle']" mode="itemstyle">

		<xsl:variable name="SafeLinkUrl">
			<xsl:call-template name="OuterTemplate.GetSafeLink">
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="SafeImageUrl">
			<xsl:call-template name="OuterTemplate.GetSafeStaticUrl">
				<xsl:with-param name="UrlColumnName" select="'Picture'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="DisplayTitle">
			<xsl:call-template name="OuterTemplate.GetTitle">
				<xsl:with-param name="Title" select="@Title"/>
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="LinkTarget">
			<xsl:if test="@OpenInNewWindow = 'True'" >_blank</xsl:if>
		</xsl:variable>
        
		<xsl:variable name="Article">
			<xsl:call-template name="removeMarkup">
				<xsl:with-param name="string" select="@Article"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="Created">
			<xsl:value-of select="ddwrt:FormatDateTime(string(@Date) ,1033 ,'MM.dd.yyyy')" />
		</xsl:variable>

		<xsl:variable name="back">
			<xsl:value-of select="concat('/pediatriccoe',$SafeLinkUrl,'&amp;source=/pediatriccoe/Pages/RegulatoryEU.aspx')" />
		</xsl:variable>
        
		<div id="BiotechnewsStyle" class="pcd">        
			<a href="{$back}" target="{$LinkTarget}" title="{@LinkToolTip}" class="titel">
				<xsl:value-of select="$DisplayTitle"/>
			</a>
			<xsl:value-of select="substring($Article, 0, 120)" disable-output-escaping="yes" />...   	         
		</div>
	</xsl:template>

	<xsl:template name="PediatricCoEBoardStyle" match="Row[@Style='PediatricCoEBoardStyle']" mode="itemstyle">
        
		<xsl:variable name="SafeLinkUrl">
			<xsl:call-template name="OuterTemplate.GetSafeLink">
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="LinkTarget">
			<xsl:if test="@OpenInNewWindow = 'True'" >_blank</xsl:if>
		</xsl:variable>

		<xsl:variable name="DisplayTitle">
			<xsl:call-template name="OuterTemplate.GetTitle">
				<xsl:with-param name="Title" select="@Title"/>
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>  
        
		<xsl:variable name="SafeImageUrl">
			<xsl:call-template name="OuterTemplate.GetSafeStaticUrl">
				<xsl:with-param name="UrlColumnName" select="'Picture'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="back">
			<xsl:value-of select="concat('/pediatriccoe',$SafeLinkUrl,'&amp;source=/pediatriccoe/Pages/blt.aspx')" />
		</xsl:variable>
    	
		<div id="PMOboardStyle" class="PMOboardDIV">
		<table>
			<tr>
			<td>
			<xsl:if test="string-length($SafeImageUrl) != 0"> 
				<a href="{$back}" target="{$LinkTarget}">
				<img class="image" src="{$SafeImageUrl}" alt="{@ImageUrlAltText}" />
				</a>
			</xsl:if>
			<a href="{$back}" target="{$LinkTarget}" title="{@LinkToolTip}" style="font-weight:bold;font-family:'Verdana';font-size:16px;COLOR: #400040;;display:block;margin-bottom:10px;">
			<xsl:value-of select="$DisplayTitle"/>
			</a>
			<span style="FONT-FAMILY: 'Verdana','sans-serif'; COLOR: #400040;"><xsl:value-of select="@Function"/></span><br/>
			<a href="mailto:{@Email}" style="color:#357fbe;margin-top:10px;display:block;"><xsl:value-of select="@Email"/></a>
			</td>
			</tr>
		</table>
	        </div>
	</xsl:template>

	<xsl:template name="PediatricCoEHappeningStyle" match="Row[@Style='PediatricCoEHappeningStyle']" mode="itemstyle">
        
		<xsl:variable name="SafeLinkUrl">
			<xsl:call-template name="OuterTemplate.GetSafeLink">
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="LinkTarget">
			<xsl:if test="@OpenInNewWindow = 'True'" >_blank</xsl:if>
		</xsl:variable>

		<xsl:variable name="DisplayTitle">
			<xsl:call-template name="OuterTemplate.GetTitle">
				<xsl:with-param name="Title" select="@Title"/>
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>   
        
		<xsl:variable name="DateM">
 			<xsl:value-of select="ddwrt:FormatDateTime(string(@Date) ,1033 ,'MMM')" />
		</xsl:variable>
		
		<xsl:variable name="DateD">
 			<xsl:value-of select="ddwrt:FormatDateTime(string(@Date) ,1033 ,'dd')" />
		</xsl:variable>


		<div id="happeningStyle" class="happeningDIV">
        
	        	<p>
			<span class="maand"><xsl:value-of select="$DateM"/></span>
			<span class="dag"><xsl:value-of select="$DateD"/></span>
			<a href="{$SafeLinkUrl}" target="{$LinkTarget}" title="{@LinkToolTip}" style="color:#357fbe;">
				<xsl:value-of select="$DisplayTitle"/>
			</a>
			<xsl:value-of select="@Location"/>
			</p>
		</div>

	</xsl:template>

	<xsl:template name="PediatricCoEvideoStyle" match="Row[@Style='PediatricCoEvideoStyle']" mode="itemstyle"> 
    
		<xsl:variable name="DisplayTitle">
			<xsl:call-template name="OuterTemplate.GetTitle">
				<xsl:with-param name="Title" select="@Title"/>
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="SafeImageUrl">
			<xsl:call-template name="OuterTemplate.GetSafeStaticUrl">
				<xsl:with-param name="UrlColumnName" select="'Picture'"/>
			</xsl:call-template>
		</xsl:variable>

    
		<xsl:variable name="URL">
			<xsl:value-of select="substring-before(@URL,',')"/>
		</xsl:variable>

		<div id="vidoeStyle" class="videoDIV">
        
			<xsl:if test="string-length($SafeImageUrl) != 0"> 
				<a href="{$URL}" target="_blank"><img class="image" src="{$SafeImageUrl}" /></a>
			</xsl:if>

			<a href="{$URL}" target="_blank">
				<xsl:value-of select="$DisplayTitle"/>
			</a>
			<xsl:value-of select="@Duration"/>
		</div>
	</xsl:template>

<!-- end item styles for Pediatric CoE -->

</xsl:stylesheet>